pm4py.algo.enhancement.organizational\_mining package
=====================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.enhancement.organizational_mining.local_diagnostics

Submodules
----------

pm4py.algo.enhancement.organizational\_mining.util module
---------------------------------------------------------

.. automodule:: pm4py.algo.enhancement.organizational_mining.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.enhancement.organizational_mining
   :members:
   :undoc-members:
   :show-inheritance:
